package produce

import (
	"query-service/internal/drivers/brokerdriver"
	"query-service/internal/drivers/keyvaluedriver"

	"github.com/streadway/amqp"
)

// Service wraps consumer methods
type Service struct {
	brokerDriver   brokerdriver.Broker
	keyValueStore  keyvaluedriver.KeyValueStore
	producerDriver brokerdriver.Producer
}

// NewService creates a new service
func NewService(broker brokerdriver.Broker, keyValueStore keyvaluedriver.KeyValueStore) *Service {
	return &Service{
		brokerDriver:  broker,
		keyValueStore: keyValueStore,
	}
}

// Start starts the producer
func (s *Service) Start() {
	// Create producer
	p := s.brokerDriver.CreateProducer()

	s.producerDriver = p

	// // Start consuming messages
	// p.ConsumeMessages()
}

// PublishMessage will publish the message to the queue retrieved from the key value store, with the given sessionID
func (s *Service) PublishMessage(data *[]byte, sessionID *string) {
	clientUpdaterID := s.keyValueStore.Get(sessionID)

	headers := amqp.Table{}
	headers["sessionID"] = sessionID
	headers["type"] = "queryResult"
	s.producerDriver.PublishMessage(data, clientUpdaterID, &headers)
}
